@@ -1,4 +1,4 @@
-# This file is part of CycloneDX Python Lib
+# This file is part of CycloneDX Python Library
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,31 +16,37 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 
-import warnings
 from datetime import datetime
 from itertools import chain
 from typing import TYPE_CHECKING, Generator, Iterable, Optional, Union
 from uuid import UUID, uuid4
+from warnings import warn
 
 import serializable
 from sortedcontainers import SortedSet
 
+from .._internal.time import get_now_utc as _get_now_utc
 from ..exception.model import LicenseExpressionAlongWithOthersException, UnknownComponentDependencyException
-from ..parser import BaseParser
 from ..schema.schema import (
     SchemaVersion1Dot0,
     SchemaVersion1Dot1,
     SchemaVersion1Dot2,
     SchemaVersion1Dot3,
     SchemaVersion1Dot4,
+    SchemaVersion1Dot5,
+    SchemaVersion1Dot6,
 )
 from ..serialization import LicenseRepositoryHelper, UrnUuidHelper
-from . import ExternalReference, OrganizationalContact, OrganizationalEntity, Property, ThisTool, Tool, get_now_utc
+from . import ExternalReference, Property
 from .bom_ref import BomRef
 from .component import Component
+from .contact import OrganizationalContact, OrganizationalEntity
+from .definition import Definitions
 from .dependency import Dependable, Dependency
 from .license import License, LicenseExpression, LicenseRepository
+from .lifecycle import Lifecycle, LifecycleRepository, _LifecycleRepositoryHelper
 from .service import Service
+from .tool import Tool, ToolRepository, _ToolRepositoryHelper
 from .vulnerability import Vulnerability
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -53,27 +59,39 @@ class BomMetaData:
     This is our internal representation of the metadata complex type within the CycloneDX standard.
 
     .. note::
-        See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.4/#type_metadata
+        See the CycloneDX Schema for Bom metadata: https://cyclonedx.org/docs/1.5/#type_metadata
     """
 
-    def __init__(self, *, tools: Optional[Iterable[Tool]] = None,
-                 authors: Optional[Iterable[OrganizationalContact]] = None, component: Optional[Component] = None,
-                 manufacture: Optional[OrganizationalEntity] = None,
-                 supplier: Optional[OrganizationalEntity] = None,
-                 licenses: Optional[Iterable[License]] = None,
-                 properties: Optional[Iterable[Property]] = None,
-                 timestamp: Optional[datetime] = None) -> None:
-        self.timestamp = timestamp or get_now_utc()
-        self.tools = tools or []  # type: ignore
-        self.authors = authors or []  # type: ignore
+    def __init__(
+        self, *,
+        tools: Optional[Union[Iterable[Tool], ToolRepository]] = None,
+        authors: Optional[Iterable[OrganizationalContact]] = None,
+        component: Optional[Component] = None,
+        supplier: Optional[OrganizationalEntity] = None,
+        licenses: Optional[Iterable[License]] = None,
+        properties: Optional[Iterable[Property]] = None,
+        timestamp: Optional[datetime] = None,
+        manufacturer: Optional[OrganizationalEntity] = None,
+        lifecycles: Optional[Iterable[Lifecycle]] = None,
+        # Deprecated as of v1.6
+        manufacture: Optional[OrganizationalEntity] = None,
+    ) -> None:
+        self.timestamp = timestamp or _get_now_utc()
+        self.tools = tools or []  # type:ignore[assignment]
+        self.authors = authors or []  # type:ignore[assignment]
         self.component = component
-        self.manufacture = manufacture
         self.supplier = supplier
-        self.licenses = licenses or []  # type: ignore
-        self.properties = properties or []  # type: ignore
+        self.licenses = licenses or []  # type:ignore[assignment]
+        self.properties = properties or []  # type:ignore[assignment]
+        self.manufacturer = manufacturer
+        self.lifecycles = lifecycles or []  # type:ignore[assignment]
 
-        if not tools:
-            self.tools.add(ThisTool)
+        self.manufacture = manufacture
+        if manufacture:
+            warn(
+                '`bom.metadata.manufacture` is deprecated from CycloneDX v1.6 onwards. '
+                'Please use `bom.metadata.component.manufacturer` instead.',
+                DeprecationWarning)
 
     @property
     @serializable.type_mapping(serializable.helpers.XsdDateTime)
@@ -92,24 +110,44 @@ class BomMetaData:
         self._timestamp = timestamp
 
     @property
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'tool')
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.type_mapping(_LifecycleRepositoryHelper)
     @serializable.xml_sequence(2)
-    def tools(self) -> 'SortedSet[Tool]':
+    def lifecycles(self) -> LifecycleRepository:
+        """
+        An optional list of BOM lifecycle stages.
+
+        Returns:
+            Set of `Lifecycle`
+        """
+        return self._lifecycles
+
+    @lifecycles.setter
+    def lifecycles(self, lifecycles: Iterable[Lifecycle]) -> None:
+        self._lifecycles = LifecycleRepository(lifecycles)
+
+    @property
+    @serializable.type_mapping(_ToolRepositoryHelper)
+    @serializable.xml_sequence(3)
+    def tools(self) -> ToolRepository:
         """
         Tools used to create this BOM.
 
         Returns:
-            `Set` of `Tool` objects.
+            :class:`ToolRepository` object.
         """
         return self._tools
 
     @tools.setter
-    def tools(self, tools: Iterable[Tool]) -> None:
-        self._tools = SortedSet(tools)
+    def tools(self, tools: Union[Iterable[Tool], ToolRepository]) -> None:
+        self._tools = tools \
+            if isinstance(tools, ToolRepository) \
+            else ToolRepository(tools=tools)
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'author')
-    @serializable.xml_sequence(3)
+    @serializable.xml_sequence(4)
     def authors(self) -> 'SortedSet[OrganizationalContact]':
         """
         The person(s) who created the BOM.
@@ -128,7 +166,7 @@ class BomMetaData:
         self._authors = SortedSet(authors)
 
     @property
-    @serializable.xml_sequence(4)
+    @serializable.xml_sequence(5)
     def component(self) -> Optional[Component]:
         """
         The (optional) component that the BOM describes.
@@ -153,7 +191,12 @@ class BomMetaData:
         self._component = component
 
     @property
-    @serializable.xml_sequence(5)
+    @serializable.view(SchemaVersion1Dot2)
+    @serializable.view(SchemaVersion1Dot3)
+    @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_sequence(6)
     def manufacture(self) -> Optional[OrganizationalEntity]:
         """
         The organization that manufactured the component that the BOM describes.
@@ -165,10 +208,32 @@ class BomMetaData:
 
     @manufacture.setter
     def manufacture(self, manufacture: Optional[OrganizationalEntity]) -> None:
+        """
+        @todo Based on https://github.com/CycloneDX/specification/issues/346,
+              we should set this data on `.component.manufacturer`.
+        """
         self._manufacture = manufacture
 
     @property
-    @serializable.xml_sequence(6)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_sequence(7)
+    def manufacturer(self) -> Optional[OrganizationalEntity]:
+        """
+        The organization that created the BOM.
+        Manufacturer is common in BOMs created through automated processes. BOMs created through manual means may have
+        `@.authors` instead.
+
+        Returns:
+            `OrganizationalEntity` if set else `None`
+        """
+        return self._manufacturer
+
+    @manufacturer.setter
+    def manufacturer(self, manufacturer: Optional[OrganizationalEntity]) -> None:
+        self._manufacturer = manufacturer
+
+    @property
+    @serializable.xml_sequence(8)
     def supplier(self) -> Optional[OrganizationalEntity]:
         """
         The organization that supplied the component that the BOM describes.
@@ -187,8 +252,10 @@ class BomMetaData:
     @property
     @serializable.view(SchemaVersion1Dot3)
     @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
     @serializable.type_mapping(LicenseRepositoryHelper)
-    @serializable.xml_sequence(7)
+    @serializable.xml_sequence(9)
     def licenses(self) -> LicenseRepository:
         """
         A optional list of statements about how this BOM is licensed.
@@ -205,8 +272,10 @@ class BomMetaData:
     @property
     @serializable.view(SchemaVersion1Dot3)
     @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'property')
-    @serializable.xml_sequence(8)
+    @serializable.xml_sequence(10)
     def properties(self) -> 'SortedSet[Property]':
         """
         Provides the ability to document properties in a key/value store. This provides flexibility to include data not
@@ -232,7 +301,7 @@ class BomMetaData:
     def __hash__(self) -> int:
         return hash((
             tuple(self.authors), self.component, tuple(self.licenses), self.manufacture, tuple(self.properties),
-            self.supplier, self.timestamp, tuple(self.tools)
+            tuple(self.lifecycles), self.supplier, self.timestamp, self.tools, self.manufacturer
         ))
 
     def __repr__(self) -> str:
@@ -244,35 +313,23 @@ class Bom:
     """
     This is our internal representation of a bill-of-materials (BOM).
 
-    You can either create a `cyclonedx.model.bom.Bom` yourself programmatically, or generate a `cyclonedx.model.bom.Bom`
-    from a `cyclonedx.parser.BaseParser` implementation.
-
     Once you have an instance of `cyclonedx.model.bom.Bom`, you can pass this to an instance of
     `cyclonedx.output.BaseOutput` to produce a CycloneDX document according to a specific schema version and format.
     """
 
-    @staticmethod
-    def from_parser(parser: BaseParser) -> 'Bom':
-        """
-        Create a Bom instance from a Parser object.
-
-        Args:
-            parser (`cyclonedx.parser.BaseParser`): A valid parser instance.
-
-        Returns:
-            `cyclonedx.model.bom.Bom`: A Bom instance that represents the valid data held in the supplied parser.
-        """
-        bom = Bom()
-        bom.components.update(parser.get_components())
-        return bom
-
-    def __init__(self, *, components: Optional[Iterable[Component]] = None,
-                 services: Optional[Iterable[Service]] = None,
-                 external_references: Optional[Iterable[ExternalReference]] = None,
-                 serial_number: Optional[UUID] = None, version: int = 1,
-                 metadata: Optional[BomMetaData] = None,
-                 dependencies: Optional[Iterable[Dependency]] = None,
-                 vulnerabilities: Optional[Iterable[Vulnerability]] = None) -> None:
+    def __init__(
+        self, *,
+        components: Optional[Iterable[Component]] = None,
+        services: Optional[Iterable[Service]] = None,
+        external_references: Optional[Iterable[ExternalReference]] = None,
+        serial_number: Optional[UUID] = None,
+        version: int = 1,
+        metadata: Optional[BomMetaData] = None,
+        dependencies: Optional[Iterable[Dependency]] = None,
+        vulnerabilities: Optional[Iterable[Vulnerability]] = None,
+        properties: Optional[Iterable[Property]] = None,
+        definitions: Optional[Definitions] = None,
+    ) -> None:
         """
         Create a new Bom that you can manually/programmatically add data to later.
 
@@ -280,13 +337,15 @@ class Bom:
             New, empty `cyclonedx.model.bom.Bom` instance.
         """
         self.serial_number = serial_number or uuid4()
-        self.metadata = metadata or BomMetaData()
-        self.components = components or []  # type: ignore
-        self.services = services or []  # type: ignore
-        self.external_references = SortedSet(external_references or [])
-        self.vulnerabilities = SortedSet(vulnerabilities or [])
         self.version = version
-        self.dependencies = SortedSet(dependencies) or SortedSet()
+        self.metadata = metadata or BomMetaData()
+        self.components = components or []  # type:ignore[assignment]
+        self.services = services or []  # type:ignore[assignment]
+        self.external_references = external_references or []  # type:ignore[assignment]
+        self.vulnerabilities = vulnerabilities or []  # type:ignore[assignment]
+        self.dependencies = dependencies or []  # type:ignore[assignment]
+        self.properties = properties or []  # type:ignore[assignment]
+        self.definitions = definitions or Definitions()
 
     @property
     @serializable.type_mapping(UrnUuidHelper)
@@ -294,6 +353,8 @@ class Bom:
     @serializable.view(SchemaVersion1Dot2)
     @serializable.view(SchemaVersion1Dot3)
     @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
     @serializable.xml_attribute()
     def serial_number(self) -> UUID:
         """
@@ -309,11 +370,22 @@ class Bom:
     def serial_number(self, serial_number: UUID) -> None:
         self._serial_number = serial_number
 
+    @property
+    @serializable.xml_attribute()
+    def version(self) -> int:
+        return self._version
+
+    @version.setter
+    def version(self, version: int) -> None:
+        self._version = version
+
     @property
     @serializable.view(SchemaVersion1Dot2)
     @serializable.view(SchemaVersion1Dot3)
     @serializable.view(SchemaVersion1Dot4)
-    @serializable.xml_sequence(1)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_sequence(10)
     def metadata(self) -> BomMetaData:
         """
         Get our internal metadata object for this Bom.
@@ -334,7 +406,7 @@ class Bom:
     @serializable.include_none(SchemaVersion1Dot0)
     @serializable.include_none(SchemaVersion1Dot1)
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'component')
-    @serializable.xml_sequence(2)
+    @serializable.xml_sequence(20)
     def components(self) -> 'SortedSet[Component]':
         """
         Get all the Components currently in this Bom.
@@ -348,6 +420,157 @@ class Bom:
     def components(self, components: Iterable[Component]) -> None:
         self._components = SortedSet(components)
 
+    @property
+    @serializable.view(SchemaVersion1Dot2)
+    @serializable.view(SchemaVersion1Dot3)
+    @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'service')
+    @serializable.xml_sequence(30)
+    def services(self) -> 'SortedSet[Service]':
+        """
+        Get all the Services currently in this Bom.
+
+        Returns:
+             Set of `Service` in this BOM
+        """
+        return self._services
+
+    @services.setter
+    def services(self, services: Iterable[Service]) -> None:
+        self._services = SortedSet(services)
+
+    @property
+    @serializable.view(SchemaVersion1Dot1)
+    @serializable.view(SchemaVersion1Dot2)
+    @serializable.view(SchemaVersion1Dot3)
+    @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'reference')
+    @serializable.xml_sequence(40)
+    def external_references(self) -> 'SortedSet[ExternalReference]':
+        """
+        Provides the ability to document external references related to the BOM or to the project the BOM describes.
+
+        Returns:
+            Set of `ExternalReference`
+        """
+        return self._external_references
+
+    @external_references.setter
+    def external_references(self, external_references: Iterable[ExternalReference]) -> None:
+        self._external_references = SortedSet(external_references)
+
+    @property
+    @serializable.view(SchemaVersion1Dot2)
+    @serializable.view(SchemaVersion1Dot3)
+    @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'dependency')
+    @serializable.xml_sequence(50)
+    def dependencies(self) -> 'SortedSet[Dependency]':
+        return self._dependencies
+
+    @dependencies.setter
+    def dependencies(self, dependencies: Iterable[Dependency]) -> None:
+        self._dependencies = SortedSet(dependencies)
+
+    # @property
+    # ...
+    # @serializable.view(SchemaVersion1Dot3)
+    # @serializable.view(SchemaVersion1Dot4)
+    # @serializable.view(SchemaVersion1Dot5)
+    # @serializable.xml_sequence(6)
+    # def compositions(self) -> ...:
+    #     ...  # TODO Since CDX 1.3
+    #
+    # @compositions.setter
+    # def compositions(self, ...) -> None:
+    #     ...  # TODO Since CDX 1.3
+
+    @property
+    # @serializable.view(SchemaVersion1Dot3) @todo: Update py-serializable to support view by OutputFormat filtering
+    # @serializable.view(SchemaVersion1Dot4) @todo: Update py-serializable to support view by OutputFormat filtering
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'property')
+    @serializable.xml_sequence(70)
+    def properties(self) -> 'SortedSet[Property]':
+        """
+        Provides the ability to document properties in a name/value store. This provides flexibility to include data
+        not officially supported in the standard without having to use additional namespaces or create extensions.
+        Property names of interest to the general public are encouraged to be registered in the CycloneDX Property
+        Taxonomy - https://github.com/CycloneDX/cyclonedx-property-taxonomy. Formal registration is OPTIONAL.
+
+        Return:
+            Set of `Property`
+        """
+        return self._properties
+
+    @properties.setter
+    def properties(self, properties: Iterable[Property]) -> None:
+        self._properties = SortedSet(properties)
+
+    @property
+    @serializable.view(SchemaVersion1Dot4)
+    @serializable.view(SchemaVersion1Dot5)
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'vulnerability')
+    @serializable.xml_sequence(80)
+    def vulnerabilities(self) -> 'SortedSet[Vulnerability]':
+        """
+        Get all the Vulnerabilities in this BOM.
+
+        Returns:
+             Set of `Vulnerability`
+        """
+        return self._vulnerabilities
+
+    @vulnerabilities.setter
+    def vulnerabilities(self, vulnerabilities: Iterable[Vulnerability]) -> None:
+        self._vulnerabilities = SortedSet(vulnerabilities)
+
+    # @property
+    # ...
+    # @serializable.view(SchemaVersion1Dot5)
+    # @serializable.xml_sequence(9)
+    # def annotations(self) -> ...:
+    #     ... # TODO Since CDX 1.5
+    #
+    # @annotations.setter
+    # def annotations(self, ...) -> None:
+    #     ...  # TODO Since CDX 1.5
+
+    # @property
+    # ...
+    # @serializable.view(SchemaVersion1Dot5)
+    # @formulation.xml_sequence(10)
+    # def formulation(self) -> ...:
+    #     ... # TODO Since CDX 1.5
+    #
+    # @formulation.setter
+    # def formulation(self, ...) -> None:
+    #     ...  # TODO Since CDX 1.5
+
+    @property
+    @serializable.view(SchemaVersion1Dot6)
+    @serializable.xml_sequence(110)
+    def definitions(self) -> Optional[Definitions]:
+        """
+        The repository for definitions
+
+        Returns:
+            `DefinitionRepository`
+        """
+        return self._definitions if len(self._definitions.standards) > 0 else None
+
+    @definitions.setter
+    def definitions(self, definitions: Definitions) -> None:
+        self._definitions = definitions
+
     def get_component_by_purl(self, purl: Optional['PackageURL']) -> Optional[Component]:
         """
         Get a Component already in the Bom by its PURL
@@ -388,45 +611,6 @@ class Bom:
         """
         return component in self.components
 
-    @property
-    @serializable.view(SchemaVersion1Dot2)
-    @serializable.view(SchemaVersion1Dot3)
-    @serializable.view(SchemaVersion1Dot4)
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'service')
-    @serializable.xml_sequence(3)
-    def services(self) -> 'SortedSet[Service]':
-        """
-        Get all the Services currently in this Bom.
-
-        Returns:
-             Set of `Service` in this BOM
-        """
-        return self._services
-
-    @services.setter
-    def services(self, services: Iterable[Service]) -> None:
-        self._services = SortedSet(services)
-
-    @property
-    @serializable.view(SchemaVersion1Dot1)
-    @serializable.view(SchemaVersion1Dot2)
-    @serializable.view(SchemaVersion1Dot3)
-    @serializable.view(SchemaVersion1Dot4)
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'reference')
-    @serializable.xml_sequence(4)
-    def external_references(self) -> 'SortedSet[ExternalReference]':
-        """
-        Provides the ability to document external references related to the BOM or to the project the BOM describes.
-
-        Returns:
-            Set of `ExternalReference`
-        """
-        return self._external_references
-
-    @external_references.setter
-    def external_references(self, external_references: Iterable[ExternalReference]) -> None:
-        self._external_references = SortedSet(external_references)
-
     def _get_all_components(self) -> Generator[Component, None, None]:
         if self.metadata.component:
             yield from self.metadata.component.get_all_nested_components(include_self=True)
@@ -460,63 +644,23 @@ class Bom:
         """
         return bool(self.vulnerabilities)
 
-    @property
-    @serializable.view(SchemaVersion1Dot4)
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'vulnerability')
-    @serializable.xml_sequence(8)
-    def vulnerabilities(self) -> 'SortedSet[Vulnerability]':
-        """
-        Get all the Vulnerabilities in this BOM.
-
-        Returns:
-             Set of `Vulnerability`
-        """
-        return self._vulnerabilities
-
-    @vulnerabilities.setter
-    def vulnerabilities(self, vulnerabilities: Iterable[Vulnerability]) -> None:
-        self._vulnerabilities = SortedSet(vulnerabilities)
-
-    @property
-    @serializable.xml_attribute()
-    def version(self) -> int:
-        return self._version
-
-    @version.setter
-    def version(self, version: int) -> None:
-        self._version = version
-
-    @property
-    @serializable.view(SchemaVersion1Dot2)
-    @serializable.view(SchemaVersion1Dot3)
-    @serializable.view(SchemaVersion1Dot4)
-    @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'dependency')
-    @serializable.xml_sequence(5)
-    def dependencies(self) -> 'SortedSet[Dependency]':
-        return self._dependencies
-
-    @dependencies.setter
-    def dependencies(self, dependencies: Iterable[Dependency]) -> None:
-        self._dependencies = SortedSet(dependencies)
-
     def register_dependency(self, target: Dependable, depends_on: Optional[Iterable[Dependable]] = None) -> None:
         _d = next(filter(lambda _d: _d.ref == target.bom_ref, self.dependencies), None)
-
-        if _d and depends_on:
+        if _d:
             # Dependency Target already registered - but it might have new dependencies to add
-            _d.dependencies = _d.dependencies.union(  # type: ignore
-                set(map(lambda _d: Dependency(ref=_d.bom_ref), depends_on)) if depends_on else []
-            )
-        elif not _d:
+            if depends_on:
+                _d.dependencies.update(map(lambda _d: Dependency(ref=_d.bom_ref), depends_on))
+        else:
             # First time we are seeing this target as a Dependency
             self._dependencies.add(Dependency(
                 ref=target.bom_ref,
                 dependencies=map(lambda _dep: Dependency(ref=_dep.bom_ref), depends_on) if depends_on else []
             ))
 
-        # Ensure dependents are registered with no further dependents in the Dependency Graph as per CDX specification
-        for _d2 in depends_on if depends_on else []:
-            self.register_dependency(target=_d2, depends_on=None)
+        if depends_on:
+            # Ensure dependents are registered with no further dependents in the DependencyGraph
+            for _d2 in depends_on:
+                self.register_dependency(target=_d2, depends_on=None)
 
     def urn(self) -> str:
         return f'urn:cdx:{self.serial_number}/{self.version}'
@@ -547,7 +691,7 @@ class Bom:
         dependency_diff = dependency_bom_refs - component_bom_refs
         if len(dependency_diff) > 0:
             raise UnknownComponentDependencyException(
-                f'One or more Components have Dependency references to Components/Services that are not known in this '
+                'One or more Components have Dependency references to Components/Services that are not known in this '
                 f'BOM. They are: {dependency_diff}')
 
         # 2. if root component is set: dependencies should exist for the Component this BOM is describing
@@ -555,10 +699,10 @@ class Bom:
             lambda d: d.ref == self.metadata.component.bom_ref and len(d.dependencies) > 0,  # type: ignore[union-attr]
             self.dependencies
         )):
-            warnings.warn(
+            warn(
                 f'The Component this BOM is describing {self.metadata.component.purl} has no defined dependencies '
-                f'which means the Dependency Graph is incomplete - you should add direct dependencies to this '
-                f'"root" Component to complete the Dependency Graph data.',
+                'which means the Dependency Graph is incomplete - you should add direct dependencies to this '
+                '"root" Component to complete the Dependency Graph data.',
                 category=UserWarning, stacklevel=1
             )
 
@@ -585,7 +729,8 @@ class Bom:
     def __hash__(self) -> int:
         return hash((
             self.serial_number, self.version, self.metadata, tuple(self.components), tuple(self.services),
-            tuple(self.external_references), tuple(self.vulnerabilities), tuple(self.dependencies)
+            tuple(self.external_references), tuple(self.dependencies), tuple(self.properties),
+            tuple(self.vulnerabilities),
         ))
 
     def __repr__(self) -> str:
